@@ -15,7 +15,7 @@ fn ssh_to_https_url(repo_url: &str) -> Option<String> {
     if !is_valid_github_repo_path(repo_path) {
         return None;
     }
-    Some(format!("https://github.com/{}", repo_path))
+    Some(format!("https://github.com/{repo_path}"))
 }
 
 fn is_valid_github_repo_path(repo_path: &str) -> bool {
@@ -123,10 +123,7 @@ pub fn clone_repository(args: &Cli, dest_path: &Path) -> FeludaResult<()> {
 
         log(
             LogLevel::Info,
-            &format!(
-                "Credentials callback for URL: {}, username: {:?}",
-                url, username_from_url
-            ),
+            &format!("Credentials callback for URL: {url}, username: {username_from_url:?}"),
         );
         if allowed_types.is_ssh_key() {
             log(LogLevel::Info, "Attempting SSH authentication");
@@ -154,7 +151,7 @@ pub fn clone_repository(args: &Cli, dest_path: &Path) -> FeludaResult<()> {
                     Err(e) => {
                         log(
                             LogLevel::Warn,
-                            &format!("SSH agent failed: {}, trying default key", e),
+                            &format!("SSH agent failed: {e}, trying default key"),
                         );
                         Err(e)
                     }
@@ -188,7 +185,7 @@ pub fn clone_repository(args: &Cli, dest_path: &Path) -> FeludaResult<()> {
                 if let Some(https_url) = ssh_to_https_url(repo_url) {
                     log(
                         LogLevel::Warn,
-                        &format!("SSH clone failed: {}, trying HTTPS: {}", e, https_url),
+                        &format!("SSH clone failed: {e}, trying HTTPS: {https_url}"),
                     );
                     let mut https_callbacks = git2::RemoteCallbacks::new();
                     https_callbacks.credentials(|_url, _username, allowed_types| {
@@ -215,22 +212,17 @@ pub fn clone_repository(args: &Cli, dest_path: &Path) -> FeludaResult<()> {
                             Ok(())
                         }
                         Err(e) => {
-                            log(LogLevel::Error, &format!("HTTPS clone failed: {}", e));
+                            log(LogLevel::Error, &format!("HTTPS clone failed: {e}"));
                             Err(FeludaError::Unknown(format!(
-                                "Failed to clone repository: {}",
-                                e
+                                "Failed to clone repository: {e}"
                             )))
                         }
                     };
                 }
             }
-            log(
-                LogLevel::Error,
-                &format!("Failed to clone repository: {}", e),
-            );
+            log(LogLevel::Error, &format!("Failed to clone repository: {e}"));
             Err(FeludaError::Unknown(format!(
-                "Failed to clone repository: {}",
-                e
+                "Failed to clone repository: {e}"
             )))
         }
     }
@@ -444,6 +436,7 @@ mod tests {
             incompatible: false,
             fail_on_incompatible: false,
             project_license: None,
+            gist: false,
         };
 
         let result = clone_repository(&args, temp_dir.path());
@@ -495,6 +488,7 @@ mod tests {
             incompatible: false,
             fail_on_incompatible: false,
             project_license: None,
+            gist: false,
         };
 
         // Enable debug mode for this test
@@ -545,6 +539,7 @@ mod tests {
             incompatible: false,
             fail_on_incompatible: false,
             project_license: None,
+            gist: false,
         };
 
         let result = clone_repository(&args, temp_dir.path());
@@ -583,13 +578,13 @@ mod tests {
         // Test very long usernames/repos
         let long_username = "a".repeat(40);
         assert_eq!(
-            ssh_to_https_url(&format!("git@github.com:{}/repo.git", long_username)),
+            ssh_to_https_url(&format!("git@github.com:{long_username}/repo.git")),
             None
         );
 
         let long_repo = "a".repeat(101);
         assert_eq!(
-            ssh_to_https_url(&format!("git@github.com:user/{}.git", long_repo)),
+            ssh_to_https_url(&format!("git@github.com:user/{long_repo}.git")),
             None
         );
 
